==> jc-1.4.0.tar.gz: polyglot/ext/jl/types/PlaceHolder__5fc.h <==
// public class polyglot.ext.jl.types.PlaceHolder_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 300fa797ed91bf2a polyglot_ext_jl_types_PlaceHolder__5fc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_types_PlaceHolder__5fc_H_
#define _JC_polyglot_ext_jl_types_PlaceHolder__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Resolver$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeObject$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *);
extern void _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$_init$5763de465c84f66b(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$resolve$02b702e0a13f36ff(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$translate$e4b604a436fc8e30(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method_info$resolve$02b702e0a13f36ff;
extern _jc_method _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method_info$translate$e4b604a436fc8e30;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods {
	struct _jc_object	*(*resolve$02b702e0a13f36ff)(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *);
	struct _jc_java_lang_String$object	*(*translate$e4b604a436fc8e30)(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods	polyglot_ext_jl_types_PlaceHolder__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs {
    _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs	polyglot_ext_jl_types_PlaceHolder__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs	polyglot_ext_jl_types_PlaceHolder__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object {
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype _jc_polyglot_ext_jl_types_PlaceHolder__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_PlaceHolder__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_PlaceHolder__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_PlaceHolder__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/types/PlaceHolder__5fc.h <==
// public class polyglot.ext.jl.types.PlaceHolder_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 300fa797ed91bf2a polyglot_ext_jl_types_PlaceHolder__5fc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_types_PlaceHolder__5fc_H_
#define _JC_polyglot_ext_jl_types_PlaceHolder__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Resolver$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeObject$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$_init$5763de465c84f66b(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$resolve$02b702e0a13f36ff(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_PlaceHolder__5fc$method$translate$e4b604a436fc8e30(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method_info$resolve$02b702e0a13f36ff;
extern _jc_method _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_types_PlaceHolder__5fc$method_info$translate$e4b604a436fc8e30;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods {
	struct _jc_object	*(*resolve$02b702e0a13f36ff)(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*translate$e4b604a436fc8e30)(_jc_env *, struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vmethods	polyglot_ext_jl_types_PlaceHolder__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs {
    _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_refs	polyglot_ext_jl_types_PlaceHolder__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_PlaceHolder__5fc$sub_nonrefs	polyglot_ext_jl_types_PlaceHolder__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_PlaceHolder__5fc$object {
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_PlaceHolder__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_PlaceHolder__5fc$vtype _jc_polyglot_ext_jl_types_PlaceHolder__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_PlaceHolder__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_PlaceHolder__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_PlaceHolder__5fc_H_ */
